@@ -36,9 +36,11 @@ class Server:
                 method_inargs[method.name] = tuple(
                     arg.signature for arg in method.in_args)
 
-            con.register_object(object_path=path,
-                                interface_info=interface,
-                                method_call_closure=self.on_method_call)
+            con.register_object(path,
+                                interface,
+                                self.on_method_call,
+                                None,
+                                None)
 
         self.method_inargs = method_inargs
         self.method_outargs = method_outargs
