@@ -156,7 +156,7 @@ def create_dir(path):
 def install_youtube_dl():
     try:
         path = GLib.get_user_data_dir() + "/lollypop/python"
-        argv = ["pip3", "install", "-t", path, "-U", "youtube-dl"]
+        argv = ["pip3", "install", "-t", path, "-U", "yt-dlp"]
         GLib.spawn_sync(None, argv, [], GLib.SpawnFlags.SEARCH_PATH, None)
     except Exception as e:
         Logger.error("install_youtube_dl: %s" % e)
@@ -169,13 +169,13 @@ def get_youtube_dl():
     """
     if App().settings.get_value("recent-youtube-dl"):
         python_path = GLib.get_user_data_dir() + "/lollypop/python"
-        path = "%s/bin/youtube-dl" % python_path
+        path = "%s/bin/yt-dlp" % python_path
         env = ["PYTHONPATH=%s" % python_path]
         f = Gio.File.new_for_path(path)
         if f.query_exists():
             return (path, env)
-    if GLib.find_program_in_path("youtube-dl"):
-        return ("youtube-dl", [])
+    if GLib.find_program_in_path("yt-dlp"):
+        return ("yt-dlp", [])
     else:
         return (None, [])
 
@@ -205,11 +205,14 @@ def decodeUnicode(bites, encoding):
 
 
 def splitUnicode(data, encoding):
-    from lollypop.define import UTF_16_ENCODING, UTF_16BE_ENCODING
+    from lollypop.define import LATIN1_ENCODING, UTF_8_ENCODING, \
+        UTF_16_ENCODING, UTF_16BE_ENCODING
     try:
         (d, t) = data.split(encoding, 1)
         # Try to fix invalid UTF16
-        if encoding == UTF_16_ENCODING or encoding == UTF_16BE_ENCODING:
+        if encoding == LATIN1_ENCODING or encoding == UTF_8_ENCODING:
+            t = t.rstrip(b"\x00")
+        elif encoding == UTF_16_ENCODING or encoding == UTF_16BE_ENCODING:
             if t[1] == 0:
                 t = b''.join(t.split(b'\x00')) + b'\x00'
     except ValueError as e:
