@@ -116,12 +116,14 @@ class AlbumTracksView(TracksView):
             Return all rows
             @return [Gtk.ListBoxRow]
         """
+        self._init()
         rows = []
         for disc in self.__album.discs:
-            for widget in [
-                self._tracks_widget_left[disc.number],
-                self._tracks_widget_right[disc.number]
-            ]:
+            if disc.number in self._tracks_widget_left.keys():
+                widget = self._tracks_widget_left[disc.number]
+                rows += widget.get_children()
+            if disc.number in self._tracks_widget_right.keys():
+                widget = self._tracks_widget_right[disc.number]
                 rows += widget.get_children()
         return rows
 
@@ -206,6 +208,8 @@ class AlbumTracksView(TracksView):
         # | Column 1 | Column 2 | #
         ###########################
         for disc in self.__album.discs:
+            if disc.number not in self._tracks_widget_left.keys():
+                continue
             label = self.__get_disc_label(disc.number)
             if orientation == Gtk.Orientation.VERTICAL:
                 self._responsive_widget.attach(
@@ -260,11 +264,7 @@ class AlbumTracksView(TracksView):
                         track.id == child.track.id:
                     tracks.append(child.track)
                 child.set_state_flags(Gtk.StateFlags.NORMAL, True)
-            # Do not update album list if in party or album already available
-            playback_track = App().player.track_in_playback(track)
-            if playback_track is not None:
-                App().player.load(playback_track)
-            elif not App().player.is_party:
+            if not App().player.is_party:
                 album = Album(track.album.id, [], [])
                 album.set_tracks(tracks)
                 if not App().settings.get_value("append-albums"):
